@@ -1,14 +1,30 @@
 import logging
 from pathlib import Path
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Tuple
 
 import pandas
 from annofabapi.models import TaskPhase
 
 from annofabcli.common.utils import print_csv
+from annofabcli.statistics.table import _add_ratio_column_for_productivity_per_user
 
 logger = logging.getLogger(__name__)
 
+FILENAME_WHOLE_PEFORMANCE = "全体の生産性と品質.csv"
+FILENAME_PEFORMANCE_PER_USER = "メンバごとの生産性と品質.csv"
+FILENAME_PEFORMANCE_PER_DATE = "日毎の生産量と生産性.csv"
+FILENAME_TASK_LIST = "タスクlist.csv"
+
+
+def _get_phase_list(df_member_performance: pandas.DataFrame) -> List[str]:
+    columns = list(df_member_performance.columns)
+    phase_list = [TaskPhase.ANNOTATION.value, TaskPhase.INSPECTION.value, TaskPhase.ACCEPTANCE.value]
+    if ("monitored_worktime_hour", TaskPhase.INSPECTION.value) not in columns:
+        phase_list.remove(TaskPhase.INSPECTION.value)
+    if ("monitored_worktime_hour", TaskPhase.ACCEPTANCE.value) not in columns:
+        phase_list.remove(TaskPhase.ACCEPTANCE.value)
+    return phase_list
+
 
 class Csv:
     """
@@ -43,6 +59,22 @@ class Csv:
         logger.debug(f"{str(output_path)} を出力します。")
         df.to_csv(str(output_path), sep=",", encoding="utf_8_sig", index=False)
 
+    def _write_csv_for_series(self, filename: str, series: pandas.Series) -> None:
+        """
+        カンマ区切りでBOM UTF-8で書きこむ(Excelで開けるようにするため）
+
+        Args:
+            filename: ファイル名
+            series: pandas.Series
+
+        Returns:
+
+        """
+        output_path = Path(f"{self.outdir}/{filename}")
+        output_path.parent.mkdir(exist_ok=True, parents=True)
+        logger.debug(f"{str(output_path)} を出力します。")
+        series.to_csv(str(output_path), sep=",", encoding="utf_8_sig", header=False)
+
     @staticmethod
     def _create_required_columns(
         df: pandas.DataFrame, prior_columns: List[Any], dropped_columns: Optional[List[Any]] = None
@@ -56,7 +88,10 @@ class Csv:
         return all_columns
 
     def write_inspection_list(
-        self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None, only_error_corrected: bool = True,
+        self,
+        df: pandas.DataFrame,
+        dropped_columns: Optional[List[str]] = None,
+        only_error_corrected: bool = True,
     ) -> None:
         """
         検査コメント一覧をTSVで出力する
@@ -176,7 +211,7 @@ class Csv:
         )
 
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
-        self._write_csv(f"タスクlist.csv", df[required_columns])
+        self._write_csv(FILENAME_TASK_LIST, df[required_columns])
 
     def write_task_history_list(self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None) -> None:
         """
@@ -290,6 +325,31 @@ class Csv:
 
         self._write_csv(f"集計結果csv/集計-作業時間.csv", target_df)
 
+    def write_whole_productivity(self, df: pandas.DataFrame) -> None:
+        """
+        全体の生産性と品質をCSVで出力する。
+
+        Args:
+            df: メンバごとの生産性と品質の の情報が格納されたDataFrame
+
+        """
+        columns_for_sum = [
+            "monitored_worktime_hour",
+            "task_count",
+            "input_data_count",
+            "annotation_count",
+            "actual_worktime_hour",
+            "prediction_actual_worktime_hour",
+            "pointed_out_inspection_comment_count",
+            "rejected_count",
+        ]
+        sum_series = df[columns_for_sum].sum()
+        phase_list = _get_phase_list(df)
+
+        _add_ratio_column_for_productivity_per_user(sum_series, phase_list=phase_list)
+        sum_series = sum_series[self._get_productivity_columns(phase_list)]
+        self._write_csv_for_series(FILENAME_WHOLE_PEFORMANCE, sum_series)
+
     def write_count_summary(self, df: pandas.DataFrame) -> None:
         """
         個数に関する集計結果をCSVで出力する。
@@ -440,37 +500,8 @@ class Csv:
             return
         self._write_csv(f"タスク1個当たり作業時間/タスク1個当たり作業時間_{phase.value}.csv", df)
 
-    def write_productivity_per_user(
-        self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None, output_path: Optional[Path] = None
-    ):
-        """
-        メンバごとの生産性を出力する。
-
-        Args:
-            df:
-            dropped_columns:
-
-        Returns:
-
-        """
-
-        def get_phase_list() -> List[str]:
-            columns = list(df.columns)
-            phase_list = [TaskPhase.ANNOTATION.value, TaskPhase.INSPECTION.value, TaskPhase.ACCEPTANCE.value]
-            if ("monitored_worktime_hour", TaskPhase.INSPECTION.value) not in columns:
-                phase_list.remove(TaskPhase.INSPECTION.value)
-            if ("monitored_worktime_hour", TaskPhase.ACCEPTANCE.value) not in columns:
-                phase_list.remove(TaskPhase.ACCEPTANCE.value)
-            return phase_list
-
-        if len(df) == 0:
-            logger.info("プロジェクトメンバ一覧が0件のため出力しない")
-            return
-
-        phase_list = get_phase_list()
-
-        user_columns = [("user_id", ""), ("username", ""), ("biography", ""), ("last_working_date", "")]
-
+    @staticmethod
+    def _get_productivity_columns(phase_list: List[str]) -> List[Tuple[str, str]]:
         monitored_worktime_columns = (
             [("monitored_worktime_hour", phase) for phase in phase_list]
             + [("monitored_worktime_hour", "sum")]
@@ -500,17 +531,42 @@ class Csv:
         ]
 
         prior_columns = (
-            user_columns
-            + monitored_worktime_columns
+            monitored_worktime_columns
             + production_columns
             + actual_worktime_columns
             + productivity_columns
             + inspection_comment_columns
         )
+
+        return prior_columns
+
+    def write_productivity_per_user(
+        self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None, output_path: Optional[Path] = None
+    ):
+        """
+        メンバごとの生産性を出力する。
+
+        Args:
+            df:
+            dropped_columns:
+
+        Returns:
+
+        """
+
+        if len(df) == 0:
+            logger.info("プロジェクトメンバ一覧が0件のため出力しない")
+            return
+
+        phase_list = _get_phase_list(df)
+        value_columns = self._get_productivity_columns(phase_list)
+
+        user_columns = [("user_id", ""), ("username", ""), ("biography", ""), ("last_working_date", "")]
+        prior_columns = user_columns + value_columns
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         target_df = df[required_columns]
         if output_path is None:
-            self._write_csv(f"メンバごとの生産性と品質.csv", target_df)
+            self._write_csv(FILENAME_PEFORMANCE_PER_USER, target_df)
         else:
             print_csv(df, output=str(output_path), to_csv_kwargs=self.CSV_FORMAT)
 
@@ -557,6 +613,6 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         target_df = df[required_columns]
         if output_path is None:
-            self._write_csv(f"日毎の生産量と生産性.csv", target_df)
+            self._write_csv(FILENAME_PEFORMANCE_PER_DATE, target_df)
         else:
             print_csv(df, output=str(output_path), to_csv_kwargs=self.CSV_FORMAT)
